@@ -21,8 +21,12 @@ expect_silent(
 )
 
 
-expect_error(
-  mf_prop_typo(mtq, c("POP", "STATUS"),
-            val_order =  c("Prefere",
-                               "Sub-prefecture", "Simple municipality")
-  ))
+mob <- read.csv(system.file("csv/mob.csv", package = "mapsf"))
+mob_97209 <- mob[mob$i == 97209, ]
+mob_links <- mf_get_links(x = mtq, df = mob_97209)
+mf_map(mtq)
+expect_silent(mf_map(mob_links,c("fij", "sj"), "prop_typo", add = TRUE))
+mob_links[2, "sj"] <- NA
+expect_silent(mf_map(mob_links,c("fij", "sj"), "prop_typo",
+                     val_max=5000, add = FALSE, col_na = "red"))
+
